/*
	This will attempt to convert a text file to a Psion 3a Agenda file
	Copyright Straylight Productions, February, 1996

   note: text file must have the format of:

            USADate tab StartTime tab EndTime tab Description

         Agenda file will be created with entries for untimed (if no
         end time is specified) or timed entries (if both start and end
         time are specified

*/

parse arg filename agenda skf dross

if ~show(l, "rexxsupport.library") then
    if ~addlib("rexxsupport.library",0,-30) then
        call exit_msg("Please install the rexxsupport.library in your libs: directory before running this Genie")

signal on error
signal on syntax
signal on break_c
signal on break_d
signal on break_e
signal on halt
signal on ioerr

address command
cr = '0a'x
lf = '0a'x
tb = '09'x


if ~open(file, filename, "r")
then
	do
	echo "Unable to open "filename
	exit
	end

if abbrev('SKIP',upper(skf)) then dross=readln(file)

if ~open(afil, agenda, "w")
then
	do
	echo "Unable to open "agenda
	exit
	end


/* write out some magic numbers to keep agenda happy  */

call writech(afil,"AgendaFileType*"||'00'x)
call writech(afil,x2c('0F102000 00000000 00000000 00000000'))

line = readln(file)

do while ~eof(file)
	parse var line date1 '09'x time1 '09'x time2 '09'x text1

	date1 = translate(date1,' ','/-. ')
	parse var date1 mo da yr dross
	if (yr < 70)
	then
		yr = "20"||yr
	else
		yr = "19"||yr
	date1 = date('I',yr||mo||da,'S') + 2922 /* internal date to agenda date */

	time1=trim(time1)
	time2=trim(time2)
	
	if time1=''
	then
		time1=65535
	else
		do
		parse var time1 hr ':' mn dross
		time1 = (hr * 60) + mn
		end

	if time2=''
	then
		do
		time2=65535
		rt = 2
		rcln = 8 + length(text1)
		end
	else
		do
		parse var time2 hr ':' mn dross
		time2 = (hr * 60) + mn
		leng1 = time2 - time1
		if leng1<1 then leng1 = leng1 + 1440 /* wrap around */
		rt = 1
		rcln = 10 + length(text1)
		end

	tmp1 = d2c(rcln)
	if rcln < 256 then tmp1 = '00'x || tmp1

	c2 = substr(tmp1,2,1)
	c1 = substr(tmp1,1,1)
	c1 = bitand(c1,'0F'x)
	c1 = bitor(c1,d2c(rt * 16))
	
	call writech(afil,c2||c1)
	
	call writewd(afil,date1)
	call writewd(afil,time1)
	call writech(afil,'1b'x)
	call writech(afil,'D')
	if rt=1 then call writewd(afil,leng1)
	call writech(afil,'00'x)
	call writech(afil,d2c(length(text1)))
	call writech(afil,text1)

	line = readln(file)

end

call close(file)
call close(afil)

exit


/* functions start here */


writewd: procedure
do
	parse arg file,valu

	valu = d2c(valu)
	valu = right(valu,2,'0000'x)

	c2 = substr(valu,2,1)
	c1 = substr(valu,1,1)
	
	call writech(afil,c2||c1)
	
	return
	
end

error:
syntax:
break_c:
break_d:
break_e:
break_f:
halt:
ioerr:
novalue:
do
	call close (file)
	call close (afil)
	echo "An Arexx error has occured interpeting Arexx string: "errortext(rc)" Line "SIGL
	return
end

